==> owncloud-10.2.0.zip: owncloud/apps/systemtags/l10n/sq.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Etiketa",
    "Tagged files" : "Kartela të etiketuara",
    "Select tags to filter by" : "Përzgjidhni etiketa sipas të cilat të bëhet filtrimi",
    "Please select tags to filter by" : "Ju lutemi, përzgjidhni etiketa sipas të cilat të bëhet filtrimi",
    "No files found for the selected tags" : "S’u gjetën kartela për etiketat e përzgjedhura",
    "<strong>System tags</strong> for a file have been modified" : "U ndryshyan <strong>etiketa sistemi</strong>për një kartelë",
    "You assigned system tag %3$s" : "Caktuat etiketën e sistemit %3$s",
    "%1$s assigned system tag %3$s" : "%1$s caktoi etiketën e sistemit %3$s",
    "You unassigned system tag %3$s" : "I hoqët etiketën e sistemit %3$s",
    "%1$s unassigned system tag %3$s" : "%1$s e hoqi %3$s si etiketë sistemi",
    "You created system tag %2$s" : "Krijuat etiketën e sistemit %2$s",
    "%1$s created system tag %2$s" : "%1$s krijoi etiketën e sistemit %2$s",
    "You deleted system tag %2$s" : "Fshitë etiketën e sistemit %2$s",
    "%1$s deleted system tag %2$s" : "%1$s fshiu etiketën e sistemit %2$s",
    "You updated system tag %3$s to %2$s" : "Përditësuat etiketën e sistemit %3$s në %2$s",
    "%1$s updated system tag %3$s to %2$s" : "%1$s përditësoi etiketën e sistemit %3$s si %2$s",
    "You assigned system tag %3$s to %2$s" : "Caktuat etiketë sistemi %3$s për %2$s",
    "%1$s assigned system tag %3$s to %2$s" : "%1$s caktoi etiketën e sistemit %3$s si %2$s",
    "You unassigned system tag %3$s from %2$s" : "I hoqët %2$s etiketën e sistemit %3$s",
    "%1$s unassigned system tag %3$s from %2$s" : "%1$s hoqi prej %2$s etiketën e sistemit %3$s",
    "%s (restricted)" : "%s (e kufizuar)",
    "%s (invisible)" : "%s (e padukshme)",
    "No files in here" : "S’ka kartela këtu",
    "No entries found in this folder" : "S’u gjetën zëra në këtë dosje",
    "Name" : "Emër",
    "Size" : "Madhësi",
    "Modified" : "Ndryshuar më",
    "%s (static)" : "%s (statike)"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/systemtags/l10n/sq.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Etiketa",
    "Tagged files" : "Kartela të etiketuara",
    "Select tags to filter by" : "Përzgjidhni etiketa sipas të cilat të bëhet filtrimi",
    "Please select tags to filter by" : "Ju lutemi, përzgjidhni etiketa sipas të cilat të bëhet filtrimi",
    "No files found for the selected tags" : "S’u gjetën kartela për etiketat e përzgjedhura",
    "<strong>System tags</strong> for a file have been modified" : "U ndryshyan <strong>etiketa sistemi</strong>për një kartelë",
    "You assigned system tag %3$s" : "Caktuat etiketën e sistemit %3$s",
    "%1$s assigned system tag %3$s" : "%1$s caktoi etiketën e sistemit %3$s",
    "You unassigned system tag %3$s" : "I hoqët etiketën e sistemit %3$s",
    "%1$s unassigned system tag %3$s" : "%1$s e hoqi %3$s si etiketë sistemi",
    "You created system tag %2$s" : "Krijuat etiketën e sistemit %2$s",
    "%1$s created system tag %2$s" : "%1$s krijoi etiketën e sistemit %2$s",
    "You deleted system tag %2$s" : "Fshitë etiketën e sistemit %2$s",
    "%1$s deleted system tag %2$s" : "%1$s fshiu etiketën e sistemit %2$s",
    "You updated system tag %3$s to %2$s" : "Përditësuat etiketën e sistemit %3$s në %2$s",
    "%1$s updated system tag %3$s to %2$s" : "%1$s përditësoi etiketën e sistemit %3$s si %2$s",
    "You assigned system tag %3$s to %2$s" : "Caktuat etiketë sistemi %3$s për %2$s",
    "%1$s assigned system tag %3$s to %2$s" : "%1$s caktoi etiketën e sistemit %3$s si %2$s",
    "You unassigned system tag %3$s from %2$s" : "I hoqët %2$s etiketën e sistemit %3$s",
    "%1$s unassigned system tag %3$s from %2$s" : "%1$s hoqi prej %2$s etiketën e sistemit %3$s",
    "%s (restricted)" : "%s (e kufizuar)",
    "%s (invisible)" : "%s (e padukshme)",
    "%s (static)" : "%s (statike)",
    "No files in here" : "S’ka kartela këtu",
    "No entries found in this folder" : "S’u gjetën zëra në këtë dosje",
    "Name" : "Emër",
    "Size" : "Madhësi",
    "Modified" : "Ndryshuar më"
},
"nplurals=2; plural=(n != 1);");
